@@ -33,10 +33,10 @@ import sipconfig
 
 
 # Initialise the globals.
-pyqt_version = 0x040a04
-pyqt_version_str = "4.10.4"
+pyqt_version = 0x040b01
+pyqt_version_str = "4.11.1"
 
-sip_min_version = 0x040f05
+sip_min_version = 0x041000
 
 qt_version = 0
 qt_edition = ""
@@ -49,7 +49,7 @@ qt_datadir = None
 qt_archdatadir = None
 qt_pluginsdir = None
 qt_xfeatures = None
-qt_shared = ""
+qt_shared = ''
 qt_framework = 0
 
 # This default value will be used by the code that bootstraps the Qt
@@ -323,7 +323,8 @@ class ConfigurePyQt4:
             0x040800: "Qt_4_7_2",
             0x040803: "Qt_4_8_0",
             0x040804: "Qt_4_8_3",
-            0x050000: "Qt_4_8_4",
+            0x040806: "Qt_4_8_4",
+            0x050000: "Qt_4_8_6",
             0x060000: "Qt_5_0_0"
         }
 
@@ -377,7 +378,7 @@ class ConfigurePyQt4:
                 "new QAssistantClient(\"foo\")", extra_lib_dirs=ass_lib_dirs,
                 extra_libs=ass_libs)
 
-        if not qt_shared:
+        if qt_shared == '':
             sipconfig.inform("QtDesigner module disabled with static Qt libraries.")
         else:
             check_module("QtDesigner", "QExtensionFactory",
@@ -471,8 +472,6 @@ class ConfigurePyQt4:
                         extra_lib_dirs=[qpy_lib_dir], extra_libs=[qpy_lib])
 
         if "QtOpenGL" in pyqt_modules:
-            generate_OpenGL_extras()
-
             qpy_inc_dir, qpy_lib_dir, qpy_lib = self._qpy_directories("QtOpenGL", "qpyopengl")
 
             if opts.bigqt:
@@ -1200,73 +1199,6 @@ def remove_file(fname):
         pass
 
 
-def generate_OpenGL_extras():
-    """Generate the extras needed by the QtOpenGL module (i.e. the .sip file
-    defining the correct typedefs for the OpenGL data types.
-    """
-    sipconfig.inform("Determining the OpenGL data types...")
-
-    src = "opengl_extras.cpp"
-
-    f = open(src, "w")
-
-    f.write(
-"""#include <QFile>
-#include <QTextStream>
-#include <qgl.h>
-
-int main(int, char **)
-{
-    QFile outf("./sip/QtOpenGL/opengl_types.sip");
-
-    if (!outf.open(QIODevice::WriteOnly|QIODevice::Truncate|QIODevice::Text))
-        return 1;
-
-    QTextStream out(&outf);
-
-    if (sizeof (long) == sizeof (GLint))
-        out << "typedef long GLint;\\n";
-    else
-        out << "typedef int GLint;\\n";
-
-    if (sizeof (unsigned long) == sizeof (GLuint))
-        out << "typedef unsigned long GLuint;\\n";
-    else
-        out << "typedef unsigned GLuint;\\n";
-
-    if (sizeof (unsigned long) == sizeof (GLenum))
-        out << "typedef unsigned long GLenum;\\n";
-    else
-        out << "typedef unsigned GLenum;\\n";
-
-    if (sizeof (unsigned long) == sizeof (GLbitfield))
-        out << "typedef unsigned long GLbitfield;\\n";
-    else
-        out << "typedef unsigned GLbitfield;\\n";
-
-    out << "typedef float GLfloat;\\n";
-
-    return 0;
-}
-""")
-
-    f.close()
-
-    cmd = compile_qt_program(src, "QtOpenGL")
-
-    if cmd is None:
-        sipconfig.error("Unable to determine the OpenGL data types.")
-
-    # SIP's build system (specifically ProgramMakefile.build_command()) assumes
-    # that an executable can be created by running a single command.  In the
-    # case of MSVC this is incorrect.  As a quick hack we do the extra step
-    # here if it looks like it is needed.
-    if os.access("opengl_extras.manifest", os.F_OK):
-        run_command("mt -nologo -manifest opengl_extras.manifest -outputresource:opengl_extras.exe;1")
-
-    run_command(cmd)
-
-
 def compile_qt_program(name, mname, extra_include_dirs=None, extra_lib_dirs=None, extra_libs=None):
     """Compile a simple Qt application.
 
@@ -1759,7 +1691,7 @@ def generate_code(mname, extra_include_dirs=None, extra_lib_dirs=None, extra_lib
 
     if qt_version >= 0x050000 and opts.with_deprecated:
         # The name of this macro is very confusing.
-        makefile.extra_defines.append('QT_DISABLE_DEPRECATED_BEFORE=0x040900')
+        makefile.extra_defines.append('QT_DISABLE_DEPRECATED_BEFORE=0x04ffff')
 
     makefile.generate()
 
@@ -1891,7 +1823,7 @@ def get_build_macros(overrides):
     if "QMAKESPEC" in list(os.environ.keys()):
         fname = os.environ["QMAKESPEC"]
 
-        if not os.path.dirname(fname):
+        if not os.path.dirname(fname) or fname.startswith("unsupported"):
             qt_macx_spec = fname
             fname = os.path.join(qt_archdatadir, "mkspecs", fname)
     elif sys.platform == "darwin":
@@ -2062,12 +1994,10 @@ SOURCES = %s
 #include <QLibraryInfo>
 #include <QTextStream>
 
-// These seem to be missing from the Qt v5 beta.
-#if !defined(QT_EDITION_DESKTOP)
-#define QT_EDITION_DESKTOP      8
-#endif
-#if !defined(QT_EDITION_OPENSOURCE)
-#define QT_EDITION_OPENSOURCE   8
+// This is for Qt v5.  The value isn't accurate but triggers the desired
+// description of the edition.
+#if !defined(QT_EDITION)
+#define QT_EDITION      0x200
 #endif
 
 int main(int argc, char **argv)
@@ -2100,7 +2030,7 @@ int main(int argc, char **argv)
 #if defined(QT_SHARED) || defined(QT_DLL)
     out << "shared\\n";
 #else
-    out << "\\n";
+    out << "static\\n";
 #endif
 
     // Determine which features should be disabled.
@@ -2229,7 +2159,9 @@ int main(int argc, char **argv)
     qt_xfeatures = lines[11:]
 
     if opts.assume_shared:
-        qt_shared = "shared"
+        qt_shared = 'shared'
+    elif qt_shared == 'static':
+        qt_shared = ''
 
     # 'Nokia' is the value that is used by Maemo's version of Qt.
     if qt_licensee in ('Open Source', 'Nokia'):
